#!/usr/bin/env python

"""
Access a Galaxy instance and get data for Datasets.
"""
import os
import sys
import pprint

import setup
import common

RESOURCE_URL = '/api/datasets'

# ----------------------------------------------------------------------------- functions
def get_datasets():
    """
    Return a list of dictionaries that describe datasets.
    """
    apikey = setup.get_apikey()
    full_url = setup.get_base_url() + RESOURCE_URL
    return common.get( apikey, full_url )

def get_dataset( dataset_id ):
    """
    Return a dictionary of detailed information for a specific dataset.
    :param dataset_id: the id of the dataset which we want to query.
    """
    apikey = setup.get_apikey()
    resource_url = setup.get_base_url() + RESOURCE_URL

    full_url = resource_url + '/' + dataset_id
    return common.get( apikey, full_url )


# ----------------------------------------------------------------------------- main
if __name__ == '__main__':
    if len( sys.argv ) <= 1:
        print 'USAGE: datasets_2.py <dataset_id>'
        sys.exit( 1 )

    dataset_id = sys.argv[1]
    returned = get_dataset( dataset_id )
    pprint.pprint( returned, indent=2 )
